@@ -9,6 +9,7 @@ from . import ono
 from . import onoObject
 from . import http_object
 from . import message_object
+from . import yss_parser
 from decimal import Decimal
 from pathlib import Path
 
@@ -692,6 +693,12 @@ class Convert():
                 result = http_object.main(input_str)
                 return result
 
+        # def check_for_yss(input_str):
+        #     m = re.search("^yss\.", input_str)
+        #     if m:
+        #         result = yss_parser.main(input_str)
+        #         return result
+
 
         # check for online .omm
         result = check_for_online_omm(omm_str)
@@ -745,6 +752,12 @@ class Convert():
         if file_check:
             omm_str = file_check
 
+        # # check for yss. YouTube subtitle search
+
+        # result = check_for_yss(omm_str)
+        # if result:
+        #     return result
+
 
         # mixtape handling
         omm_lines = split_yotas(omm_str)
@@ -810,4 +823,31 @@ class Convert():
             
 
         if len(result) > 0:
-            return myMix
\ No newline at end of file
+            return myMix
+
+
+    def api(input_str):
+        m = re.search("^yss\.", input_str)
+        if m:
+            result = yss_parser.main(input_str)
+            return result
+
+        m2 = re.search("^yts\.([^\.]+)", input_str)
+        m3 = re.search("^yts\.[^\.]+\.((\d{1,3}[hms]){1,3})$", input_str)
+        m4 = re.search("^yts\.[^\.]+\.((\d{1,3}[hms]){1,3})\.((\d{1,3}[hms]){1,3})", input_str)
+        if m2 and not m3 and not m4:
+            #print("m2 only matched...")
+            result = Convert.search_to_mixtape(m2.group(1))
+            return result
+
+        if m3 and not m4:
+            #print("m3 and not m4")
+            result = Convert.search_to_mixtape(m2.group(1)).add_time_code(m3.group(1))
+            return result
+
+        if m4:
+            #print(f"m2.group(1) (search term):{m2.group(1)}")
+            #print(f"m3.group(1) (first time code):{m3.group(1)}")
+            #print(f"m4.group(1) (second time code):{m4.group(1)}")
+            result = Convert.search_to_mixtape(m2.group(1)).add_time_code(m4.group(1), m4.group(3))
+            return result
\ No newline at end of file
