@@ -1,16 +1,16 @@
 #!/home/dd/anaconda3/bin/python
 # yn - YouTube first result new (arbitrary no. results & piping) 
-# v0.6 (Juli 24th 2020)
+# v0.53 (March 8th 2019)
 
 # Searches youtube.com and returns search result URLs.
 
-# What's New: update for new YouTube results page (href -> url)
+# What's New: remove commented-out code
 
 import sys, requests, re, logging
-from more_itertools import unique_everseen
 from . import yt_stepper
 from . import cnf
 
+
 logger = logging.getLogger("yn_logger")
 fn_fh = logging.FileHandler('mb_func.log', mode='a')
 fn_fh.setLevel(logging.DEBUG)
@@ -23,13 +23,14 @@ logger.setLevel(logging.DEBUG)
 def return_results(args, count=1):
     
     """Takes args string, returns YouTube search result(s),
-    1-2 digit trailing integer values in args interpreted as count, 
+    1-2 digit integer values in args interpreted as count, 
     default count 1."""
 
-    # NB: checks args string for trailing OVERRIDDING results count integer
-    #      (overridding a count argument if passed)
+    # NB: CHECKS FOR OVERRIDDING INTEGER VALUE count
+    # IN SEARCH TERMS (aggresively, any integer 
+    # surrounded by whitespace)
 
-    m = re.search(' (\d+)$', args)
+    m = re.search(' (\d{1,2})$', args)
     if m:
     
         count = int(m.group(1))
@@ -42,24 +43,22 @@ def return_results(args, count=1):
     else:
         today = False
 
-
     # result count limitation
     if not cnf.version_number[-3:]:
         if count > 20:
             raise ValueError("maximum 20 search results in community version")
 
-
     search_string = args.replace(" ","+")
     youtube_string = 'https://www.youtube.com/results?search_query=' + search_string
     if today:
         youtube_string += '%2C+' + m2.group(1)
-        # https://www.youtube.com/results?search_query=hak5%2C+month
+        
     urls = []
     while count > 0:
         # use 'OMM v0.9.0.4'-style user-agent
         headers = {'User-Agent': cnf.header_str}
         r = requests.get(youtube_string, headers=headers)
-        m = re.findall('href=\"\/watch\?v=([a-zA-Z_\-0-9]{11})\"', r.text)
+        m = re.findall('url\"\:\"\/watch\?v=([a-zA-Z_\-0-9]{11})\"', r.text)
         uniqued = []
         for item in m:
             if item not in uniqued:
@@ -72,25 +71,24 @@ def return_results(args, count=1):
         youtube_string = yt_stepper.next_page(youtube_string)
 
     logger.debug(f"downloaded YouTube '{args}' search results, returning {len(urls)} results")
-
     return(urls)
 
 
-if __name__ == '__main__':
+# if __name__ == '__main__':
 
-    if len(sys.argv) == 1:       # no arguments, piping mode
-        args = sys.stdin.read()  # if no piped input,
-        result = main(args)  # reads from keyboard
+#     if len(sys.argv) == 1:       # no arguments, piping mode
+#         args = sys.stdin.read()  # if no piped input,
+#         result = return_results(args)  # reads from keyboard
     
-    else:
-        args = ""
-        for item in sys.argv[1:]:
-            args = args + item
-            args += " "
-        args = args.rstrip()
-        if args:
-            result = main(args)
+#     else:
+#         args = ""
+#         for item in sys.argv[1:]:
+#             args = args + item
+#             args += " "
+#         args = args.rstrip()
+#         if args:
+#             result = return_results(args)
 
-    for url in result:
-        print(url)
+#     for url in result:
+#         print(url)
 
